See our `readthedocs`_ for the Python Data Science library documentation.

See the `API Documentation`_ for the Crossing Minds universal recommendation API documentation.

.. _readthedocs: https://xminds.readthedocs.io/en/latest/
.. _API Documentation: https://docs.api.crossingminds.com/
